from django.apps import AppConfig
from django.utils.translation import gettext_lazy as _

class DjangoDbCounterConfig(AppConfig):
    name = 'django_db_counter'
    verbose_name = _("Django DB Counter")


# Generated by Django 2.2.28 on 2022-12-21 03:14

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='DjangoDBCounter',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('key', models.CharField(db_index=True, max_length=128, verbose_name='数据库计数器关键字')),
                ('add_time', models.DateTimeField(auto_now_add=True, verbose_name='Add Time')),
                ('mod_time', models.DateTimeField(auto_now=True, verbose_name='Modify Time')),
            ],
            options={
                'verbose_name': '数据库计数记录',
                'verbose_name_plural': '数据库计数记录',
            },
        ),
    ]



from django.contrib import admin

from .models import DjangoDBCounter


class DjangoDBCounterAdmin(admin.ModelAdmin):
    list_display = ["pk", "key", "add_time", "mod_time"]
    list_filter = ["key"]


admin.site.register(DjangoDBCounter, DjangoDBCounterAdmin)




from django.db import models
from django.utils.translation import gettext as _

class DjangoDBCounterBase(models.Model):
    default_key = "default"

    key = models.CharField(max_length=128, db_index=True, verbose_name=_("Django DB Counter Key"))
    add_time = models.DateTimeField(auto_now_add=True, verbose_name=_("Add Time"))
    mod_time = models.DateTimeField(auto_now=True, verbose_name=_("Modify Time"))

    class Meta:
        abstract = True

    @classmethod
    def get_next(cls, key=None):
        key = key or cls.default_key
        item = cls(key=key)
        item.save()
        return cls.objects.filter(pk__lte=item.pk).count()

class DjangoDBCounter(DjangoDBCounterBase):

    class Meta:
        verbose_name = _("Django DB Counter Record")
        verbose_name_plural = _("Django DB Counter Records")

